==> munit-common-2.1.1-sources.jar: org/mule/munit/common/protocol/message/MessageField.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.common.protocol.message;

import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;

/**
 * Fields of the RunMessage
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class MessageField {

  public static final Charset DEFAULT_CHARSET = StandardCharsets.UTF_8;

  public static final String RUN_TOKEN_KEY = "runToken";
  public static final String MUNIT_SUITE_KEY = "munitSuite";
  public static final String NAME_KEY = "name";
  public static final String DESCRIPTION_KEY = "description";
  public static final String NUMBER_OF_TESTS_KEY = "numberOfTests";
  public static final String TEST_NAMES_KEY = "testNames";
  public static final String STACK_TRACE_KEY = "stackTrace";
  public static final String ELAPSED_TIME_KEY = "elapsedTime";
  public static final String STATUS_KEY = "status";
  public static final String TAGS_KEY = "tags";
  public static final String COVERAGE_REPORT_KEY = "coverageReport";

  public static final String SEPARATOR_TOKEN = ",";
  public static final String FIELD_TOKEN = new String(new byte[] {0x1b}, DEFAULT_CHARSET);
  public static final String NEW_LINE_ESCAPE_TOKEN = new String(new byte[] {0x1a}, DEFAULT_CHARSET);

}

==> munit-common-2.3.14-sources.jar: org/mule/munit/common/protocol/message/MessageField.java <==
/*
 * Copyright (c) 2017 MuleSoft, Inc. This software is protected under international
 * copyright law. All use of this software is subject to MuleSoft's Master Subscription
 * Agreement (or other master license agreement) separately entered into in writing between
 * you and MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package org.mule.munit.common.protocol.message;

import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;

/**
 * Fields of the RunMessage
 *
 * @author Mulesoft Inc.
 * @since 2.0.0
 */
public class MessageField {

  public static final Charset DEFAULT_CHARSET = StandardCharsets.UTF_8;

  public static final String RUN_TOKEN_KEY = "runToken";
  public static final String MUNIT_SUITE_KEY = "munitSuite";
  public static final String NAME_KEY = "name";
  public static final String DESCRIPTION_KEY = "description";
  public static final String IGNORED_KEY = "ignored";
  public static final String NUMBER_OF_TESTS_KEY = "numberOfTests";
  public static final String TEST_NAMES_KEY = "testNames";
  public static final String STACK_TRACE_KEY = "stackTrace";
  public static final String ELAPSED_TIME_KEY = "elapsedTime";
  public static final String STATUS_KEY = "status";
  public static final String TAGS_KEY = "tags";
  public static final String COVERAGE_REPORT_KEY = "coverageReport";
  public static final String PARAMETERIZATION_KEY = "parameterizationKey";

  public static final String SEPARATOR_TOKEN = ",";
  public static final String FIELD_TOKEN = new String(new byte[] {0x1b}, DEFAULT_CHARSET);
  public static final String NEW_LINE_ESCAPE_TOKEN = new String(new byte[] {0x1a}, DEFAULT_CHARSET);

}
